import { type GenesisAuthConfig, type GenesisIdentity } from '../auth/index.ts';
export type VercelGenesisAuthResult = {
    /** Continue the middleware chain when undefined. */
    response?: Response;
    identity?: GenesisIdentity;
    /** Request with genesis identity headers attached for downstream handlers. */
    request?: Request;
};
/**
 * Vercel / Edge middleware helper. Returns a response to short-circuit, or request/identity to continue.
 *
 * ```ts
 * const auth = genesisAuthVercel({ projectId });
 * export async function middleware(request: Request) {
 *   const result = await auth(request);
 *   if (result.response) return result.response;
 *   return NextResponse.next({ request: result.request ?? request });
 * }
 * ```
 */
export declare function genesisAuthVercel(config: GenesisAuthConfig): (request: Request) => Promise<VercelGenesisAuthResult>;
export declare function attachGenesisIdentityHeaders(request: Request, identity: GenesisIdentity): Request;
//# sourceMappingURL=vercel.d.ts.map