import { isStructuredError, StructuredError } from '@agentuity/core';
export const GenesisAuthError = StructuredError('GenesisAuthError')();
export function isGenesisAuthError(err) {
    return isStructuredError(err) && err._tag === 'GenesisAuthError';
}
//# sourceMappingURL=errors.js.map