import type { MiddlewareHandler } from 'hono';
import { type GenesisAuthConfig, type GenesisIdentity } from '../auth/index.ts';
export type GenesisAuthVariables = {
    genesisIdentity?: GenesisIdentity;
};
export declare function genesisAuth(config: GenesisAuthConfig): MiddlewareHandler<{
    Variables: GenesisAuthVariables;
}>;
//# sourceMappingURL=hono.d.ts.map