import { type GenesisAuthConfig, type GenesisIdentity } from '../auth/index.ts';
export type TanStackGenesisContext = {
    genesisIdentity?: GenesisIdentity;
};
export type TanStackMiddlewareArgs = {
    request: Request;
    next: (options?: {
        context?: TanStackGenesisContext;
    }) => Promise<Response>;
    context: TanStackGenesisContext;
};
/**
 * TanStack Start server middleware handler. Wrap with `createMiddleware` from `@tanstack/react-start`:
 *
 * ```ts
 * import { createMiddleware } from '@tanstack/react-start';
 * import { genesisAuthTanStackStart } from '@agentuity/genesis/tanstack-start';
 *
 * export const genesisAuth = createMiddleware().server(genesisAuthTanStackStart({ projectId }));
 * ```
 */
export declare function genesisAuthTanStackStart(config: GenesisAuthConfig): ({ request, next, context }: TanStackMiddlewareArgs) => Promise<Response>;
//# sourceMappingURL=tanstack-start.d.ts.map