import type { GenesisIdentity, UpstreamIdentitySigningKey } from './types.ts';
export declare function importVerificationKey(publicKeyPEM: string): Promise<CryptoKey>;
export declare function verifyUpstreamIdentityToken(signingKey: UpstreamIdentitySigningKey, token: string, projectId: string): Promise<GenesisIdentity>;
//# sourceMappingURL=verify.d.ts.map