export declare const GenesisAuthError: {
    new (args?: ({
        status: number;
    } & {
        message?: string;
        cause?: unknown;
    }) | undefined): import("@agentuity/adapter").RichError & {
        readonly _tag: "GenesisAuthError";
    } & Readonly<{
        status: number;
    }>;
    readonly defaultMessage?: string;
};
export type GenesisAuthErrorInstance = InstanceType<typeof GenesisAuthError>;
export declare function isGenesisAuthError(err: unknown): err is GenesisAuthErrorInstance;
//# sourceMappingURL=errors.d.ts.map