import type { UpstreamIdentitySigningKey } from './types.ts';
export declare const DEFAULT_AUTH_HUB_URL = "https://auth.agentcompany.com";
export declare const IDENTITY_SIGNING_KEY_PATH = "/.well-known/sso/identity-signing-key";
export declare const SIGNING_KEY_FETCH_TIMEOUT_MS = 10000;
export declare function resolveAuthHubUrl(configured?: string): string;
export declare function identitySigningKeyUrl(authHubUrl: string): string;
export declare function fetchIdentitySigningKey(authHubUrl: string): Promise<UpstreamIdentitySigningKey>;
//# sourceMappingURL=signing-key.d.ts.map